@@ -9,9 +9,12 @@
 #' @return A guide object
 #'
 #' @export
-guide_edge_colourbar <- function(..., available_aes = c("edge_colour", "edge_fill")) {
+guide_edge_colourbar <- function(
+  ...,
+  available_aes = c("edge_colour", "edge_fill")
+) {
   guide <- guide_colourbar(..., available_aes = available_aes)
-  guide$name <- 'edge_colourbar'
+  guide$params$name <- 'edge_colourbar'
   guide
 }
 #' @rdname guide_edge_colourbar
@@ -30,11 +33,19 @@ guide_edge_colorbar <- guide_edge_colourbar
 #' @return A guide object
 #'
 #' @export
-guide_edge_coloursteps <- function(even.steps = TRUE, show.limits = NULL, ticks = FALSE, ...,
-                                   available_aes = c("edge_colour", "edge_fill")) {
-  guide <- guide_coloursteps(even.steps = even.steps, show.limits = show.limits,
-                             ticks = ticks, ..., available_aes = available_aes)
-  guide$name <- 'edge_coloursteps'
+guide_edge_coloursteps <- function(
+  even.steps = TRUE,
+  show.limits = NULL,
+  ...,
+  available_aes = c("edge_colour", "edge_fill")
+) {
+  guide <- guide_coloursteps(
+    even.steps = even.steps,
+    show.limits = show.limits,
+    ...,
+    available_aes = available_aes
+  )
+  guide$params$name <- 'edge_coloursteps'
   guide
 }
 #' @rdname guide_edge_coloursteps
