@@ -21,7 +21,7 @@
 #'
 #' @examples
 #' library(tidygraph)
-#' gr <- as_tbl_graph(highschool) |>
+#' gr <- as_tbl_graph(highschool) %>%
 #'   mutate(popularity = as.character(cut(centrality_degree(mode = 'in'),
 #'     breaks = 3,
 #'     labels = c('low', 'medium', 'high')
@@ -32,14 +32,29 @@
 #'   facet_graph(year ~ popularity)
 #' @export
 #'
-facet_graph <- function(facets, row_type = 'edge', col_type = 'node',
-                        margins = FALSE, scales = 'fixed', space = 'fixed',
-                        shrink = TRUE, labeller = 'label_value', as.table = TRUE,
-                        switch = NULL, drop = TRUE) {
-  facet <- facet_grid(facets,
-    margins = margins, scales = scales,
-    space = space, shrink = shrink, labeller = labeller,
-    as.table = as.table, switch = switch, drop = drop
+facet_graph <- function(
+  facets,
+  row_type = 'edge',
+  col_type = 'node',
+  margins = FALSE,
+  scales = 'fixed',
+  space = 'fixed',
+  shrink = TRUE,
+  labeller = 'label_value',
+  as.table = TRUE,
+  switch = NULL,
+  drop = TRUE
+) {
+  facet <- facet_grid(
+    facets,
+    margins = margins,
+    scales = scales,
+    space = space,
+    shrink = shrink,
+    labeller = labeller,
+    as.table = as.table,
+    switch = switch,
+    drop = drop
   )
   seed <- sample(.Machine$integer.max, 1L)
   facet$params$rows[] <- lapply(seq_along(facet$params$rows), function(i) {
@@ -49,12 +64,17 @@ facet_graph <- function(facets, row_type = 'edge', col_type = 'node',
     rlang::quo(withr::with_seed(seed, !!facet$params$cols[[i]]))
   })
 
-  ggproto(NULL, FacetGraph,
+  ggproto(
+    NULL,
+    FacetGraph,
     shrink = shrink,
-    params = c(facet$params, list(
-      row_type = row_type,
-      col_type = col_type
-    ))
+    params = c(
+      facet$params,
+      list(
+        row_type = row_type,
+        col_type = col_type
+      )
+    )
   )
 }
 
@@ -62,7 +82,9 @@ facet_graph <- function(facets, row_type = 'edge', col_type = 'node',
 #' @format NULL
 #' @usage NULL
 #' @export
-FacetGraph <- ggproto('FacetGraph', FacetGrid,
+FacetGraph <- ggproto(
+  'FacetGraph',
+  FacetGrid,
   compute_layout = function(self, data, params) {
     plot_data <- data[[1]]
     data <- split(data, vapply(data, data_type, character(1)))
@@ -73,41 +95,70 @@ FacetGraph <- ggproto('FacetGraph', FacetGrid,
       params$row_type,
       node = data$node_ggraph,
       edge = data$edge_ggraph,
-      cli::cli_abort('{.arg row_type} must be either {.val node} or {.val edge}')
+      cli::cli_abort(
+        '{.arg row_type} must be either {.val node} or {.val edge}'
+      )
     )
     col_data <- switch(
       params$col_type,
       node = data$node_ggraph,
       edge = data$edge_ggraph,
-      cli::cli_abort('{.arg col_type} must be either {.val node} or {.val edge}')
+      cli::cli_abort(
+        '{.arg col_type} must be either {.val node} or {.val edge}'
+      )
     )
 
     dups <- intersect(names(rows), names(cols))
     if (length(dups) > 0 && params$col_type == params$row_type) {
-      cli::cli_abort(c(
-        "Faceting variables can only appear in {.arg rows} or {.arg cols}, not both.\n",
-        "i" = "Duplicated variables: {.val {dups}}"
-      ), call = call2(snake_class(self)))
+      cli::cli_abort(
+        c(
+          "Faceting variables can only appear in {.arg rows} or {.arg cols}, not both.\n",
+          "i" = "Duplicated variables: {.val {dups}}"
+        ),
+        call = call2(snake_class(self))
+      )
     }
 
-    base_rows <- combine_vars(row_data, params$plot_env, rows, drop = params$drop)
+    base_rows <- combine_vars(
+      row_data,
+      params$plot_env,
+      rows,
+      drop = params$drop
+    )
     if (!params$as.table) {
       rev_order <- function(x) factor(x, levels = rev(ulevels(x)))
       base_rows[] <- lapply(base_rows, rev_order)
     }
-    base_cols <- combine_vars(col_data, params$plot_env, cols, drop = params$drop)
+    base_cols <- combine_vars(
+      col_data,
+      params$plot_env,
+      cols,
+      drop = params$drop
+    )
     base <- df.grid(base_rows, base_cols)
 
     # Add margins
-    base <- reshape_add_margins(base, list(names(rows), names(cols)), params$margins)
+    base <- reshape_add_margins(
+      base,
+      list(names(rows), names(cols)),
+      params$margins
+    )
     base <- unique0(base)
 
     # Create panel info dataset
     panel <- id(base, drop = TRUE)
     panel <- factor(panel, levels = seq_len(attr(panel, 'n')))
 
-    rows <- if (length(names(rows)) == 0) 1L else id(base[names(rows)], drop = TRUE)
-    cols <- if (length(names(cols)) == 0) 1L else id(base[names(cols)], drop = TRUE)
+    rows <- if (length(names(rows)) == 0) {
+      1L
+    } else {
+      id(base[names(rows)], drop = TRUE)
+    }
+    cols <- if (length(names(cols)) == 0) {
+      1L
+    } else {
+      id(base[names(cols)], drop = TRUE)
+    }
 
     panels <- data_frame0(PANEL = panel, ROW = rows, COL = cols, base)
     panels <- panels[order(panels$PANEL), , drop = FALSE]
@@ -119,8 +170,12 @@ FacetGraph <- ggproto('FacetGraph', FacetGrid,
     node_placement <- if (nrow(base) == 0) {
       list(`1` = plot_data$.ggraph_index)
     } else {
-      if (params$row_type == 'edge') params$rows <- NULL
-      if (params$col_type == 'edge') params$cols <- NULL
+      if (params$row_type == 'edge') {
+        params$rows <- NULL
+      }
+      if (params$col_type == 'edge') {
+        params$cols <- NULL
+      }
       if (length(params$cols) == 0 && length(params$rows) == 0) {
         node_map <- rep(list(node_map$.ggraph.index), nrow(panels))
         names(node_map) <- panels$PANEL
@@ -140,17 +195,28 @@ FacetGraph <- ggproto('FacetGraph', FacetGrid,
     switch(
       data_type(data),
       edge_ggraph = {
-        if (params$row_type == 'node') params$rows <- NULL
-        if (params$col_type == 'node') params$cols <- NULL
+        if (params$row_type == 'node') {
+          params$rows <- NULL
+        }
+        if (params$col_type == 'node') {
+          params$cols <- NULL
+        }
         if (length(params$cols) == 0 && length(params$rows) == 0) {
-          edge_map <- cbind(vec_rep(data, nrow(layout)), PANEL = rep(layout$PANEL, each = nrow(data)))
+          edge_map <- cbind(
+            vec_rep(data, nrow(layout)),
+            PANEL = rep(layout$PANEL, each = nrow(data))
+          )
         } else {
           edge_map <- FacetGrid$map_data(data, layout, params)
           edge_map <- expand_facet_map(edge_map, layout)
         }
-        edge_map <- Map(function(map, nodes) {
-          map[map$from %in% nodes & map$to %in% nodes, , drop = FALSE]
-        }, map = split(edge_map, edge_map$PANEL), nodes = attr(layout, 'node_placement'))
+        edge_map <- Map(
+          function(map, nodes) {
+            map[map$from %in% nodes & map$to %in% nodes, , drop = FALSE]
+          },
+          map = split(edge_map, edge_map$PANEL),
+          nodes = attr(layout, 'node_placement')
+        )
         vec_rbind(!!!edge_map)
       },
       node_ggraph = {
@@ -161,7 +227,8 @@ FacetGraph <- ggproto('FacetGraph', FacetGrid,
         node_map <- vec_rbind(!!!node_map)
         node_map$PANEL <- factor(panel, levels = levels(layout$PANEL))
         node_map
-      }, {
+      },
+      {
         FacetGrid$map_data(data, layout, params)
       }
     )
@@ -180,7 +247,11 @@ expand_facet_map <- function(map, layout) {
       map <- lapply(split(map, as.integer(map$PANEL)), function(data) {
         row <- layout$ROW[layout$PANEL == data$PANEL[1]]
         panels <- layout$PANEL[layout$ROW == row]
-        data_expand <- data[rep(seq_len(nrow(data)), length(panels)), , drop = FALSE]
+        data_expand <- data[
+          rep(seq_len(nrow(data)), length(panels)),
+          ,
+          drop = FALSE
+        ]
         data_expand$PANEL <- rep(panels, each = nrow(data))
         data_expand
       })
@@ -193,7 +264,11 @@ expand_facet_map <- function(map, layout) {
       map <- lapply(split(map, as.integer(map$PANEL)), function(data) {
         col <- layout$COL[layout$PANEL == data$PANEL[1]]
         panels <- layout$PANEL[layout$COL == col]
-        data_expand <- data[rep(seq_len(nrow(data)), length(panels)), , drop = FALSE]
+        data_expand <- data[
+          rep(seq_len(nrow(data)), length(panels)),
+          ,
+          drop = FALSE
+        ]
         data_expand$PANEL <- rep(panels, each = nrow(data))
         data_expand
       })
@@ -206,8 +281,12 @@ expand_facet_map <- function(map, layout) {
 
 # From ggplot2
 df.grid <- function(a, b) {
-  if (is.null(a) || nrow(a) == 0) return(b)
-  if (is.null(b) || nrow(b) == 0) return(a)
+  if (is.null(a) || nrow(a) == 0) {
+    return(b)
+  }
+  if (is.null(b) || nrow(b) == 0) {
+    return(a)
+  }
 
   indexes <- expand.grid(
     i_a = seq_len(nrow(a)),
