@@ -42,11 +42,11 @@
 #'
 #' @examples
 #' require(tidygraph)
-#' gr <- create_notable('zachary') |>
-#'   mutate(group = group_infomap()) |>
-#'   morph(to_split, group) |>
-#'   activate(edges) |>
-#'   mutate(edge_group = as.character(.N()$group[1])) |>
+#' gr <- create_notable('zachary') %>%
+#'   mutate(group = group_infomap()) %>%
+#'   morph(to_split, group) %>%
+#'   activate(edges) %>%
+#'   mutate(edge_group = as.character(.N()$group[1])) %>%
 #'   unmorph()
 #'
 #' ggraph(gr, 'matrix', sort.by = node_rank_hclust()) +
@@ -60,14 +60,24 @@ NULL
 #' @rdname geom_edge_point
 #'
 #' @export
-geom_edge_point <- function(mapping = NULL, data = get_edges(),
-                            position = 'identity', mirror = FALSE,
-                            show.legend = NA, ...) {
+geom_edge_point <- function(
+  mapping = NULL,
+  data = get_edges(),
+  position = 'identity',
+  mirror = FALSE,
+  show.legend = NA,
+  ...
+) {
   mapping <- complete_edge_aes(mapping)
   mapping <- aes_intersect(mapping, aes(x = x, y = yend))
   layer(
-    data = data, mapping = mapping, stat = StatFilter, geom = GeomEdgePoint,
-    position = position, show.legend = show.legend, inherit.aes = FALSE,
+    data = data,
+    mapping = mapping,
+    stat = StatFilter,
+    geom = GeomEdgePoint,
+    position = position,
+    show.legend = show.legend,
+    inherit.aes = FALSE,
     params = list2(mirror = mirror, ...)
   )
 }
