@@ -29,18 +29,28 @@
 #'
 #' @examples
 #' require(tidygraph)
-#' gr <- create_notable('bull') |>
+#' gr <- create_notable('bull') %>%
 #'   mutate(class = sample(letters[1:3], n(), replace = TRUE))
 #'
 #' ggraph(gr, 'stress') + geom_node_point()
 #' @export
 #'
-geom_node_point <- function(mapping = NULL, data = NULL, position = 'identity',
-                            show.legend = NA, ...) {
+geom_node_point <- function(
+  mapping = NULL,
+  data = NULL,
+  position = 'identity',
+  show.legend = NA,
+  ...
+) {
   mapping <- aes_intersect(mapping, aes(x = x, y = y))
   layer(
-    data = data, mapping = mapping, stat = StatFilter, geom = GeomPoint,
-    position = position, show.legend = show.legend, inherit.aes = FALSE,
+    data = data,
+    mapping = mapping,
+    stat = StatFilter,
+    geom = GeomPoint,
+    position = position,
+    show.legend = show.legend,
+    inherit.aes = FALSE,
     params = list2(...)
   )
 }
